==> worker_2.4.0.orig.tar.gz: worker-2.4.0/src/renameop.cc <==
/* renameop.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: renameop.cc,v 1.7 2002/03/16 23:28:59 ralf Exp $ */

#include "renameop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *RenameOp::name="RenameOp";

RenameOp::RenameOp(Worker *tworker):FunctionProto(tworker)
{
}

RenameOp::~RenameOp()
{
}

RenameOp*
RenameOp::duplicate()
{
  RenameOp *ta=new RenameOp(worker);
  return ta;
}

bool
RenameOp::isName(const char *str)
{
  if(strcmp(str,name)==0) return true; else return false;
}

const char *
RenameOp::getName()
{
  return name;
}

int
RenameOp::run(ActionMessage *msg)
{
  ListerMode *lm1;
  am=msg;
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    Lister *l1=worker->getActiveLister();
    if(l1!=NULL) {
      startlister=l1;
      lm1=startlister->getActiveMode();
      if(lm1!=NULL)
        if(lm1->isType("NormalMode")==true)
          normalmoderename();
    }
  }
  return 0;
}

const char *
RenameOp::getDescription()
{
  return catalog.getLocaleCom(29);
}

int
RenameOp::normalmoderename()
{
  NormalMode *nm1=NULL;
  ListerMode *lm1=NULL;
  struct NM_renameorder renorder;
  struct NM_specialsource *specialsource=NULL;
  
  if(startlister==NULL) return 1;
  lm1=startlister->getActiveMode();
  if(lm1==NULL) return 1;
  if(lm1->isType("NormalMode")!=true) return 1;
  nm1=(NormalMode*)lm1;
  
  if(am->mode==am->AM_MODE_ONLYACTIVE)
    renorder.source=renorder.NM_ONLYACTIVE;
  else if(am->mode==am->AM_MODE_DNDACTION) {
    // insert DND-element into list
    renorder.source=renorder.NM_SPECIAL;
    renorder.sources=new List;
    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
    specialsource->entry=NULL;
    specialsource->row=-1;
    //TODO: specialsource nach am besetzen (je nachdem wir ich das realisiere)
    renorder.sources->addElement(specialsource);
  } else if(am->mode==am->AM_MODE_SPECIAL) {
    renorder.source=renorder.NM_SPECIAL;
    renorder.sources=new List;
    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
    specialsource->entry=(FileEntry*)am->extraInfo;
    specialsource->row=-1;
    renorder.sources->addElement(specialsource);
  } else
    renorder.source=renorder.NM_ALLENTRIES;

  nm1->renamef(&renorder);
  if(renorder.source==renorder.NM_SPECIAL) {
    if(specialsource!=NULL) _freesafe(specialsource);
    delete renorder.sources;
  }

  return 0;
}

==> worker_2.8.5.orig.tar.gz: worker-2.8.5/src/renameop.cc <==
/* renameop.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: renameop.cc,v 1.10 2004/03/18 07:11:04 ralf Exp $ */

#include "renameop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *RenameOp::name="RenameOp";

RenameOp::RenameOp() : FunctionProto()
{
}

RenameOp::~RenameOp()
{
}

RenameOp*
RenameOp::duplicate() const
{
  RenameOp *ta=new RenameOp();
  return ta;
}

bool
RenameOp::isName(const char *str)
{
  if(strcmp(str,name)==0) return true; else return false;
}

const char *
RenameOp::getName()
{
  return name;
}

int
RenameOp::run(ActionMessage *msg)
{
  ListerMode *lm1;
  am=msg;
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    Lister *l1 = msg->getWorker()->getActiveLister();
    if(l1!=NULL) {
      startlister=l1;
      lm1=startlister->getActiveMode();
      if(lm1!=NULL)
        if(lm1->isType("NormalMode")==true)
          normalmoderename();
    }
  }
  return 0;
}

const char *
RenameOp::getDescription()
{
  return catalog.getLocaleCom(29);
}

int
RenameOp::normalmoderename()
{
  NormalMode *nm1=NULL;
  ListerMode *lm1=NULL;
  struct NM_renameorder renorder;
  struct NM_specialsource *specialsource=NULL;
  
  if(startlister==NULL) return 1;
  lm1=startlister->getActiveMode();
  if(lm1==NULL) return 1;
  if(lm1->isType("NormalMode")!=true) return 1;
  nm1=(NormalMode*)lm1;
  
  memset( &renorder, 0, sizeof( renorder ) );
  if(am->mode==am->AM_MODE_ONLYACTIVE)
    renorder.source=renorder.NM_ONLYACTIVE;
  else if(am->mode==am->AM_MODE_DNDACTION) {
    // insert DND-element into list
    renorder.source=renorder.NM_SPECIAL;
    renorder.sources=new List;
    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
    specialsource->entry=NULL;
    specialsource->row=-1;
    //TODO: specialsource nach am besetzen (je nachdem wir ich das realisiere)
    renorder.sources->addElement(specialsource);
  } else if(am->mode==am->AM_MODE_SPECIAL) {
    renorder.source=renorder.NM_SPECIAL;
    renorder.sources=new List;
    specialsource=(struct NM_specialsource*)_allocsafe(sizeof(struct NM_specialsource));
    specialsource->entry=(FileEntry*)am->extraInfo;
    specialsource->row=-1;
    renorder.sources->addElement(specialsource);
  } else
    renorder.source=renorder.NM_ALLENTRIES;

  nm1->renamef(&renorder);
  if(renorder.source==renorder.NM_SPECIAL) {
    if(specialsource!=NULL) _freesafe(specialsource);
    delete renorder.sources;
  }

  return 0;
}
